@@ -8,5 +8,5 @@ import sys
 ROOT = os.path.dirname(sys.argv[0])
 WDM_DIR = os.path.join(ROOT, ".wdm")
 WDM_CHROMIUM_DIR = os.path.join(WDM_DIR, "chromium")
-LOG_FILE = os.path.join(ROOT, "open_webdriver.log")
 WDM_DIR = os.path.join(ROOT, ".wdm")
+LOG_FILE = os.path.join(WDM_DIR, "open_webdriver.log")
